pub enum Delta {
Missing,
NoMatch {
cmp: Leaf,
},
Ok,
Excess,
}Expand description
Describes a difference between an original and compared file.
Missing: The file is missing.
NoMatch: Some file metadata doesn’t match, such as file content or mode (on
Unix).
Excess: The file isn’t present in the original file tree, but exists in the
compared file tree. In this case, an attached Leaf alongside this delta will likely
refer to the excess file.
Ok: The file is present and equal.
Variants